@@ -17,10 +17,10 @@ local({
     if (! (snowlib %in% .libPaths()))
         .libPaths(c(snowlib, .libPaths()))
     library(methods) ## because Rscript as of R 2.7.0 doesn't load methods
-    library(Rmpi)
-    library(snow)
+    loadNamespace("Rmpi")
+    loadNamespace("snow")
 
     #sinkWorkerOutput(outfile)
-    cat("starting MPI worker\n")
+    message("starting MPI worker\n")
     BiocParallel::bprunMPIslave()
 })
