@@ -21,11 +21,10 @@ local({
     if (! (snowlib %in% .libPaths()))
         .libPaths(c(snowlib, .libPaths()))
     library(methods) ## because Rscript as of R 2.7.0 doesn't load methods
-    library(snow)
+    loadNamespace("snow")
 
     if (port == "") port <- getClusterOption("port")
 
-    #sinkWorkerOutput(outfile)  ## use 'logdir' instead
-    cat("starting worker for", paste(master, port, sep = ":"), "\n")
-    BiocParallel::bpslaveLoop(makeSOCKmaster(master, port))
+    message("starting worker ", master, ":", port)
+    BiocParallel::bploop(snow::makeSOCKmaster(master, port))
 })
